# -*- coding: utf-8 -*-
# Generated by Django 1.11.7 on 2017-11-09 07:07
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djworkspace', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='cache',
            name='key',
            field=models.CharField(max_length=100),
        ),
        migrations.AlterField(
            model_name='cache',
            name='type',
            field=models.CharField(max_length=100),
        ),
    ]
