# -*- coding: utf-8 -*-
# Generated by Django 1.11.7 on 2017-11-09 07:23
from __future__ import unicode_literals

from django.db import migrations
import picklefield.fields


class Migration(migrations.Migration):

    dependencies = [
        ('djworkspace', '0002_auto_20171109_0707'),
    ]

    operations = [
        migrations.AlterField(
            model_name='cache',
            name='results',
            field=picklefield.fields.PickledObjectField(editable=False, null=True),
        ),
    ]
